from setuptools import setup

setup(name='funniest1',
      version='0.1',
      description='The funniest joke in the world',
      author='Flying Circus',
      license='MIT',
      packages=['funniest1'],
      zip_safe=False)
